@@ -10,21 +10,25 @@
 #    LICENSE file in the root directory of this source tree.
 ############################################################################
 
-from scqubits import FullZeroPi
-from scqubits.core.spectrum import SpectrumData
+
+import pytest
+
+import scqubits as qubit
+from scqubits.core.storage import SpectrumData
 from scqubits.tests.conftest import BaseTest, DATADIR
 
 
+@pytest.mark.usefixtures("io_type")
 class TestFullZeroPi(BaseTest):
     @classmethod
     def setup_class(cls):
         cls.qbt = None
-        cls.qbt_type = FullZeroPi
+        cls.qbt_type = qubit.FullZeroPi
         cls.file_str = 'fullzeropi'
 
-    def test_eigenvals(self):
-        testname = self.file_str + '_1'
-        specdata = SpectrumData.create_from_fileread(DATADIR + testname)
+    def test_eigenvals(self, io_type):
+        testname = self.file_str + '_1.' + io_type
+        specdata = SpectrumData.create_from_file(DATADIR + testname)
         self.qbt = self.qbt_type.create_from_dict(specdata._get_metadata_dict())
         evals_reference = specdata.energy_table
-        return self.eigenvals(evals_reference)
+        return self.eigenvals(io_type, evals_reference)
